==> commons-utils-2.11.0-sources.jar: org/seppiko/commons/utils/http/DefaultX509TrustManager.java <==
/*
 * Copyright 2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils.http;

import java.net.Socket;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import javax.net.ssl.SSLEngine;
import javax.net.ssl.X509ExtendedTrustManager;

/**
 * Default X509 Trust Manager,
 * Trust all certificates by default.
 *
 * @author Leonard Woo
 */
public class DefaultX509TrustManager extends X509ExtendedTrustManager {

  /** X509 Trust Manager Constructor */
  public DefaultX509TrustManager() {
  }

  /** {@inheritDoc} */
  @Override
  public void checkClientTrusted(X509Certificate[] chain, String authType, Socket socket)
      throws CertificateException {

  }

  /** {@inheritDoc} */
  @Override
  public void checkClientTrusted(X509Certificate[] chain, String authType, SSLEngine engine)
      throws CertificateException {

  }

  /** {@inheritDoc} */
  @Override
  public void checkClientTrusted(X509Certificate[] chain, String authType)
      throws CertificateException {
    checkClientTrusted(chain, authType, (SSLEngine) null);
  }

  /** {@inheritDoc} */
  @Override
  public void checkServerTrusted(X509Certificate[] chain, String authType, Socket socket)
      throws CertificateException {
  }

  /** {@inheritDoc} */
  @Override
  public void checkServerTrusted(X509Certificate[] chain, String authType, SSLEngine engine)
      throws CertificateException {
  }

  /** {@inheritDoc} */
  @Override
  public void checkServerTrusted(X509Certificate[] chain, String authType)
      throws CertificateException {
    checkServerTrusted(chain, authType, (SSLEngine) null);
  }

  /** {@inheritDoc} */
  @Override
  public X509Certificate[] getAcceptedIssuers() {
    return new X509Certificate[0];
  }
}

==> commons-utils-2.12.0-sources.jar: org/seppiko/commons/utils/http/DefaultX509TrustManager.java <==
/*
 * Copyright 2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils.http;

import java.net.Socket;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import javax.net.ssl.SSLEngine;
import javax.net.ssl.X509ExtendedTrustManager;

/**
 * Default X509 Trust Manager, trust all certificates.
 *
 * @author Leonard Woo
 */
public class DefaultX509TrustManager extends X509ExtendedTrustManager {

  /** X509 Trust Manager Constructor */
  public DefaultX509TrustManager() {
  }

  /** {@inheritDoc} */
  @Override
  public void checkClientTrusted(X509Certificate[] chain, String authType, Socket socket)
      throws CertificateException {
  }

  /** {@inheritDoc} */
  @Override
  public void checkClientTrusted(X509Certificate[] chain, String authType, SSLEngine engine)
      throws CertificateException {
  }

  /** {@inheritDoc} */
  @Override
  public void checkClientTrusted(X509Certificate[] chain, String authType)
      throws CertificateException {
    checkClientTrusted(chain, authType, (SSLEngine) null);
  }

  /** {@inheritDoc} */
  @Override
  public void checkServerTrusted(X509Certificate[] chain, String authType, Socket socket)
      throws CertificateException {
  }

  /** {@inheritDoc} */
  @Override
  public void checkServerTrusted(X509Certificate[] chain, String authType, SSLEngine engine)
      throws CertificateException {
  }

  /** {@inheritDoc} */
  @Override
  public void checkServerTrusted(X509Certificate[] chain, String authType)
      throws CertificateException {
    checkServerTrusted(chain, authType, (SSLEngine) null);
  }

  /** {@inheritDoc} */
  @Override
  public X509Certificate[] getAcceptedIssuers() {
    return new X509Certificate[0];
  }
}
